function bsmr = tbx_cfg_bsm
% MATLABBATCH Configuration file for toolbox 'BSM'
%_______________________________________________________________________
% Copyright (C) 2015 NeuroImaging Center Groningen

% Jan-Bernard Marsman

if ~isdeployed
    addpath(fullfile(spm('Dir'),'toolbox','BSM'));
end


spms         = cfg_files;
spms.tag     = 'spms';
spms.name    = 'SPM models';
spms.help    = {'Select SPM models for Beta Series correlation.'};
spms.filter = 'any';
spms.ufilter = '^SPM.mat';
spms.num     = [1 Inf];


rois         = cfg_files;
rois.tag     = 'rois';
rois.name    = 'Regions of Interest';
rois.help    = {'Select ROIs for Beta Series Correlation.'};
rois.filter = 'image';
rois.ufilter = '.nii';
rois.num     = [1 Inf];


acfl = cfg_entry;
acfl.tag = 'acfl';
acfl.name = 'Exclude columns from BSM models';
acfl.help = {'Exclude columns from BSM models. Leave empty when all conditions should be taken into account. If you have a varying number of columns it is also possible to use the keyword end, in that case use single quotes around the entry (e.g., ''7:end'' '};
acfl.val = {[]};

target = cfg_entry;
target.tag = 'target';
target.name = 'Output folder';
target.help = {'If specific target location is preferred, specify here. If it is not specified the default location',...
    'will be used, i.e. <location of SPM.mat> /BSM'};
target.val = {'BSM'};


keepfl = cfg_menu;
keepfl.tag     = 'keepfl';
keepfl.name    = 'Save Intermediate GLM models';
keepfl.help    = {'Do you want to save the intermediate GLMs (only the beta is used...'};
keepfl.labels = {
                'Yes'
                'No'
                }';
keepfl.values = { 1 0 };
keepfl.val    = {1};


keepr = cfg_menu;
keepr.tag     = 'keepr';
keepr.name    = 'Retain motion regressors';
keepr.help    = {'Do you want to keep the motion regressors'};
keepr.labels = {
                'Yes'
                'No'
                }';
keepr.values = { 1 0 };
keepr.val    = {1};

type = cfg_menu;
type.tag     = 'type';
type.name    = 'Type of Beta Series modelling';
type.help    = {'Types of modelling : ',...
                '1) Traditional Rissman et al (2004): One model per event comprising two columns: one event column, other conditions other events)',...
                '2) Traditional Rissman et al (2004) adapted: One model per event comprising N+1 columns: one event column, other events, conditions in different columns',...
                '3) Faster approach Mumford et al(2012); :One model per condition, all events from a single condition separated in columns, other conditions modeled as original'};
            
type.labels = {
                'Traditional Rissman et al (2004)',...
                'Adapted Rissman et al (2004)',...
                'Fast approach',...
                'Adapted Fast approach'};                
type.values = { 1 2 3 4};
type.val    = {3};

bsm = cfg_exbranch;
bsm.tag     = 'bsm';
bsm.name    = 'Beta Series Modelling (BSM)';
bsm.val     = { spms rois acfl type keepfl keepr };
bsm.help    = {'Beta Series correlations: Consists of four parts: 1) Estimation of models with separate betas per event. 2) Concatenation of beta series 3) Regress Per ROI timecourse on the beta series 4) Calculate contrast of betas from regression models in step 3.'};
bsm.prog = @spm_bsm;


bsmr = cfg_choice;
bsmr.tag     = 'bsmr';
bsmr.name    = 'BSM';
bsmr.help    = {''};
bsmr.values  = {bsm};



